@@ -993,8 +993,7 @@ namespace Private {
         );
       }
     } else {
-      // Import an environment
-
+      // Create the environment from the requirements
       INotification.update({
         toastId,
         message: `Creating conda environment ${environmentName}... Please wait`
@@ -1002,7 +1001,7 @@ namespace Private {
 
       try {
         if (file) {
-          // Create the environment from the requirements
+          // Import an environment
           await conda.import(environmentName, file, ENVIRONMENT_FILE);
         } else {
           // Create an environment
@@ -1141,7 +1140,7 @@ namespace Private {
     isIdentical: boolean;
     conda?: string;
     file?: string;
-    notInFile?: Set<string>;
+    notInFile: Set<string>;
   }> {
     let conda: string;
     let condaPkgs: Set<string>;
@@ -1203,7 +1202,15 @@ namespace Private {
     }
 
     const isIdentical = conda === file;
-    const notInFile = new Set([...condaPkgs].filter(pkg => !filePkgs.has(pkg)));
+
+    let notInFile = new Set<string>();
+    if (!isIdentical && condaPkgs) {
+      if (filePkgs) {
+        notInFile = new Set([...condaPkgs].filter(pkg => !filePkgs.has(pkg)));
+      } else {
+        notInFile = condaPkgs;
+      }
+    }
 
     return { isIdentical, conda, file, notInFile };
   }
